/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200809L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#ifdef _WIN32
#  define inline _inline
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <errno.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
#ifdef EISDIR
	dump("defined", 1);
	if ((EISDIR) <= 0) {
	    long long x = (long long)(EISDIR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EISDIR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_1(void) {
#ifdef EPROTONOSUPPORT
	dump("defined", 1);
	if ((EPROTONOSUPPORT) <= 0) {
	    long long x = (long long)(EPROTONOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROTONOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_2(void) {
#ifdef ENOPKG
	dump("defined", 1);
	if ((ENOPKG) <= 0) {
	    long long x = (long long)(ENOPKG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOPKG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_3(void) {
#ifdef WSAENETRESET
	dump("defined", 1);
	if ((WSAENETRESET) <= 0) {
	    long long x = (long long)(WSAENETRESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENETRESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_4(void) {
#ifdef WSAECONNREFUSED
	dump("defined", 1);
	if ((WSAECONNREFUSED) <= 0) {
	    long long x = (long long)(WSAECONNREFUSED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAECONNREFUSED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_5(void) {
#ifdef ETOOMANYREFS
	dump("defined", 1);
	if ((ETOOMANYREFS) <= 0) {
	    long long x = (long long)(ETOOMANYREFS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ETOOMANYREFS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_6(void) {
#ifdef EDEADLOCK
	dump("defined", 1);
	if ((EDEADLOCK) <= 0) {
	    long long x = (long long)(EDEADLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDEADLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_7(void) {
#ifdef ETIME
	dump("defined", 1);
	if ((ETIME) <= 0) {
	    long long x = (long long)(ETIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ETIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_8(void) {
#ifdef ESOCKTNOSUPPORT
	dump("defined", 1);
	if ((ESOCKTNOSUPPORT) <= 0) {
	    long long x = (long long)(ESOCKTNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESOCKTNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_9(void) {
#ifdef ENOTTY
	dump("defined", 1);
	if ((ENOTTY) <= 0) {
	    long long x = (long long)(ENOTTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_10(void) {
#ifdef ENAMETOOLONG
	dump("defined", 1);
	if ((ENAMETOOLONG) <= 0) {
	    long long x = (long long)(ENAMETOOLONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENAMETOOLONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_11(void) {
#ifdef ENETRESET
	dump("defined", 1);
	if ((ENETRESET) <= 0) {
	    long long x = (long long)(ENETRESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENETRESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_12(void) {
#ifdef WSAGETASYNCBUFLE
	dump("defined", 1);
	if ((WSAGETASYNCBUFLE) <= 0) {
	    long long x = (long long)(WSAGETASYNCBUFLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAGETASYNCBUFLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_13(void) {
#ifdef EAGAIN
	dump("defined", 1);
	if ((EAGAIN) <= 0) {
	    long long x = (long long)(EAGAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAGAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_14(void) {
#ifdef WSAMAKESELECTREPL
	dump("defined", 1);
	if ((WSAMAKESELECTREPL) <= 0) {
	    long long x = (long long)(WSAMAKESELECTREPL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAMAKESELECTREPL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_15(void) {
#ifdef ENOLINK
	dump("defined", 1);
	if ((ENOLINK) <= 0) {
	    long long x = (long long)(ENOLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_16(void) {
#ifdef ERFKILL
	dump("defined", 1);
	if ((ERFKILL) <= 0) {
	    long long x = (long long)(ERFKILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERFKILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_17(void) {
#ifdef ECONNRESET
	dump("defined", 1);
	if ((ECONNRESET) <= 0) {
	    long long x = (long long)(ECONNRESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECONNRESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_18(void) {
#ifdef EL3HLT
	dump("defined", 1);
	if ((EL3HLT) <= 0) {
	    long long x = (long long)(EL3HLT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EL3HLT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_19(void) {
#ifdef ELIBEXEC
	dump("defined", 1);
	if ((ELIBEXEC) <= 0) {
	    long long x = (long long)(ELIBEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELIBEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_20(void) {
#ifdef EDEVERR
	dump("defined", 1);
	if ((EDEVERR) <= 0) {
	    long long x = (long long)(EDEVERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDEVERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_21(void) {
#ifdef WSAETOOMANYREFS
	dump("defined", 1);
	if ((WSAETOOMANYREFS) <= 0) {
	    long long x = (long long)(WSAETOOMANYREFS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAETOOMANYREFS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_22(void) {
#ifdef EINPROGRESS
	dump("defined", 1);
	if ((EINPROGRESS) <= 0) {
	    long long x = (long long)(EINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_23(void) {
#ifdef EUCLEAN
	dump("defined", 1);
	if ((EUCLEAN) <= 0) {
	    long long x = (long long)(EUCLEAN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EUCLEAN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_24(void) {
#ifdef ENOTSOCK
	dump("defined", 1);
	if ((ENOTSOCK) <= 0) {
	    long long x = (long long)(ENOTSOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTSOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_25(void) {
#ifdef ESPIPE
	dump("defined", 1);
	if ((ESPIPE) <= 0) {
	    long long x = (long long)(ESPIPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESPIPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_26(void) {
#ifdef ENOLCK
	dump("defined", 1);
	if ((ENOLCK) <= 0) {
	    long long x = (long long)(ENOLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_27(void) {
#ifdef EDEADLK
	dump("defined", 1);
	if ((EDEADLK) <= 0) {
	    long long x = (long long)(EDEADLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDEADLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_28(void) {
#ifdef EFBIG
	dump("defined", 1);
	if ((EFBIG) <= 0) {
	    long long x = (long long)(EFBIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EFBIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_29(void) {
#ifdef EBADRQC
	dump("defined", 1);
	if ((EBADRQC) <= 0) {
	    long long x = (long long)(EBADRQC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADRQC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_30(void) {
#ifdef ECANCELED
	dump("defined", 1);
	if ((ECANCELED) <= 0) {
	    long long x = (long long)(ECANCELED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECANCELED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_31(void) {
#ifdef WSAEDQUOT
	dump("defined", 1);
	if ((WSAEDQUOT) <= 0) {
	    long long x = (long long)(WSAEDQUOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEDQUOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_32(void) {
#ifdef WSAEMSGSIZE
	dump("defined", 1);
	if ((WSAEMSGSIZE) <= 0) {
	    long long x = (long long)(WSAEMSGSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEMSGSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_33(void) {
#ifdef EXFULL
	dump("defined", 1);
	if ((EXFULL) <= 0) {
	    long long x = (long long)(EXFULL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXFULL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_34(void) {
#ifdef WSAEPFNOSUPPORT
	dump("defined", 1);
	if ((WSAEPFNOSUPPORT) <= 0) {
	    long long x = (long long)(WSAEPFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEPFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_35(void) {
#ifdef ENOPOLICY
	dump("defined", 1);
	if ((ENOPOLICY) <= 0) {
	    long long x = (long long)(ENOPOLICY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOPOLICY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_36(void) {
#ifdef EEXIST
	dump("defined", 1);
	if ((EEXIST) <= 0) {
	    long long x = (long long)(EEXIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EEXIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_37(void) {
#ifdef EMSGSIZE
	dump("defined", 1);
	if ((EMSGSIZE) <= 0) {
	    long long x = (long long)(EMSGSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EMSGSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_38(void) {
#ifdef EPROTO
	dump("defined", 1);
	if ((EPROTO) <= 0) {
	    long long x = (long long)(EPROTO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROTO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_39(void) {
#ifdef WSAEPROTONOSUPPORT
	dump("defined", 1);
	if ((WSAEPROTONOSUPPORT) <= 0) {
	    long long x = (long long)(WSAEPROTONOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEPROTONOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_40(void) {
#ifdef EL3RST
	dump("defined", 1);
	if ((EL3RST) <= 0) {
	    long long x = (long long)(EL3RST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EL3RST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_41(void) {
#ifdef WSAENAMETOOLONG
	dump("defined", 1);
	if ((WSAENAMETOOLONG) <= 0) {
	    long long x = (long long)(WSAENAMETOOLONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENAMETOOLONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_42(void) {
#ifdef EREMOTEIO
	dump("defined", 1);
	if ((EREMOTEIO) <= 0) {
	    long long x = (long long)(EREMOTEIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EREMOTEIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_43(void) {
#ifdef ESRMNT
	dump("defined", 1);
	if ((ESRMNT) <= 0) {
	    long long x = (long long)(ESRMNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESRMNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_44(void) {
#ifdef WSAEADDRNOTAVAIL
	dump("defined", 1);
	if ((WSAEADDRNOTAVAIL) <= 0) {
	    long long x = (long long)(WSAEADDRNOTAVAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEADDRNOTAVAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_45(void) {
#ifdef WSAHOS
	dump("defined", 1);
	if ((WSAHOS) <= 0) {
	    long long x = (long long)(WSAHOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAHOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_46(void) {
#ifdef EKEYEXPIRED
	dump("defined", 1);
	if ((EKEYEXPIRED) <= 0) {
	    long long x = (long long)(EKEYEXPIRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EKEYEXPIRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_47(void) {
#ifdef WSAEINTR
	dump("defined", 1);
	if ((WSAEINTR) <= 0) {
	    long long x = (long long)(WSAEINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_48(void) {
#ifdef EIDRM
	dump("defined", 1);
	if ((EIDRM) <= 0) {
	    long long x = (long long)(EIDRM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EIDRM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_49(void) {
#ifdef EADDRNOTAVAIL
	dump("defined", 1);
	if ((EADDRNOTAVAIL) <= 0) {
	    long long x = (long long)(EADDRNOTAVAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EADDRNOTAVAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_50(void) {
#ifdef ETXTBSY
	dump("defined", 1);
	if ((ETXTBSY) <= 0) {
	    long long x = (long long)(ETXTBSY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ETXTBSY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_51(void) {
#ifdef ENOTACTIVE
	dump("defined", 1);
	if ((ENOTACTIVE) <= 0) {
	    long long x = (long long)(ENOTACTIVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTACTIVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_52(void) {
#ifdef WSAENOBUFS
	dump("defined", 1);
	if ((WSAENOBUFS) <= 0) {
	    long long x = (long long)(WSAENOBUFS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENOBUFS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_53(void) {
#ifdef EPERM
	dump("defined", 1);
	if ((EPERM) <= 0) {
	    long long x = (long long)(EPERM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPERM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_54(void) {
#ifdef ENOTUNIQ
	dump("defined", 1);
	if ((ENOTUNIQ) <= 0) {
	    long long x = (long long)(ENOTUNIQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTUNIQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_55(void) {
#ifdef WSAETIMEDOUT
	dump("defined", 1);
	if ((WSAETIMEDOUT) <= 0) {
	    long long x = (long long)(WSAETIMEDOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAETIMEDOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_56(void) {
#ifdef ELNRNG
	dump("defined", 1);
	if ((ELNRNG) <= 0) {
	    long long x = (long long)(ELNRNG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELNRNG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_57(void) {
#ifdef WSAGETSELECTERRO
	dump("defined", 1);
	if ((WSAGETSELECTERRO) <= 0) {
	    long long x = (long long)(WSAGETSELECTERRO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAGETSELECTERRO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_58(void) {
#ifdef WSAECONNRESET
	dump("defined", 1);
	if ((WSAECONNRESET) <= 0) {
	    long long x = (long long)(WSAECONNRESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAECONNRESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_59(void) {
#ifdef WSAEBADF
	dump("defined", 1);
	if ((WSAEBADF) <= 0) {
	    long long x = (long long)(WSAEBADF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEBADF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_60(void) {
#ifdef ENOSPC
	dump("defined", 1);
	if ((ENOSPC) <= 0) {
	    long long x = (long long)(ENOSPC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOSPC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_61(void) {
#ifdef ENOTNAM
	dump("defined", 1);
	if ((ENOTNAM) <= 0) {
	    long long x = (long long)(ENOTNAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTNAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_62(void) {
#ifdef EREMCHG
	dump("defined", 1);
	if ((EREMCHG) <= 0) {
	    long long x = (long long)(EREMCHG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EREMCHG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_63(void) {
#ifdef EISCONN
	dump("defined", 1);
	if ((EISCONN) <= 0) {
	    long long x = (long long)(EISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_64(void) {
#ifdef WSAEADDRINUSE
	dump("defined", 1);
	if ((WSAEADDRINUSE) <= 0) {
	    long long x = (long long)(WSAEADDRINUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEADDRINUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_65(void) {
#ifdef ELIBBAD
	dump("defined", 1);
	if ((ELIBBAD) <= 0) {
	    long long x = (long long)(ELIBBAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELIBBAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_66(void) {
#ifdef WSAEHOSTDOWN
	dump("defined", 1);
	if ((WSAEHOSTDOWN) <= 0) {
	    long long x = (long long)(WSAEHOSTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEHOSTDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_67(void) {
#ifdef ENOANO
	dump("defined", 1);
	if ((ENOANO) <= 0) {
	    long long x = (long long)(ENOANO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOANO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_68(void) {
#ifdef WSAEREMOTE
	dump("defined", 1);
	if ((WSAEREMOTE) <= 0) {
	    long long x = (long long)(WSAEREMOTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEREMOTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_69(void) {
#ifdef ESTALE
	dump("defined", 1);
	if ((ESTALE) <= 0) {
	    long long x = (long long)(ESTALE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESTALE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_70(void) {
#ifdef ENOPROTOOPT
	dump("defined", 1);
	if ((ENOPROTOOPT) <= 0) {
	    long long x = (long long)(ENOPROTOOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOPROTOOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_71(void) {
#ifdef WSAEPROCLIM
	dump("defined", 1);
	if ((WSAEPROCLIM) <= 0) {
	    long long x = (long long)(WSAEPROCLIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEPROCLIM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_72(void) {
#ifdef WSAENOTEMPTY
	dump("defined", 1);
	if ((WSAENOTEMPTY) <= 0) {
	    long long x = (long long)(WSAENOTEMPTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENOTEMPTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_73(void) {
#ifdef ENOATTR
	dump("defined", 1);
	if ((ENOATTR) <= 0) {
	    long long x = (long long)(ENOATTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOATTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_74(void) {
#ifdef WSAEDESTADDRREQ
	dump("defined", 1);
	if ((WSAEDESTADDRREQ) <= 0) {
	    long long x = (long long)(WSAEDESTADDRREQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEDESTADDRREQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_75(void) {
#ifdef ELIBMAX
	dump("defined", 1);
	if ((ELIBMAX) <= 0) {
	    long long x = (long long)(ELIBMAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELIBMAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_76(void) {
#ifdef WSATR
	dump("defined", 1);
	if ((WSATR) <= 0) {
	    long long x = (long long)(WSATR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSATR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_77(void) {
#ifdef ELOOP
	dump("defined", 1);
	if ((ELOOP) <= 0) {
	    long long x = (long long)(ELOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_78(void) {
#ifdef ECHILD
	dump("defined", 1);
	if ((ECHILD) <= 0) {
	    long long x = (long long)(ECHILD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHILD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_79(void) {
#ifdef EAUTH
	dump("defined", 1);
	if ((EAUTH) <= 0) {
	    long long x = (long long)(EAUTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAUTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_80(void) {
#ifdef EREMOTE
	dump("defined", 1);
	if ((EREMOTE) <= 0) {
	    long long x = (long long)(EREMOTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EREMOTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_81(void) {
#ifdef WSAENOPROTOOPT
	dump("defined", 1);
	if ((WSAENOPROTOOPT) <= 0) {
	    long long x = (long long)(WSAENOPROTOOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENOPROTOOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_82(void) {
#ifdef ENOTRECOVERABLE
	dump("defined", 1);
	if ((ENOTRECOVERABLE) <= 0) {
	    long long x = (long long)(ENOTRECOVERABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTRECOVERABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_83(void) {
#ifdef ENOBUFS
	dump("defined", 1);
	if ((ENOBUFS) <= 0) {
	    long long x = (long long)(ENOBUFS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOBUFS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_84(void) {
#ifdef EDESTADDRREQ
	dump("defined", 1);
	if ((EDESTADDRREQ) <= 0) {
	    long long x = (long long)(EDESTADDRREQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDESTADDRREQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_85(void) {
#ifdef EINTR
	dump("defined", 1);
	if ((EINTR) <= 0) {
	    long long x = (long long)(EINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_86(void) {
#ifdef EADV
	dump("defined", 1);
	if ((EADV) <= 0) {
	    long long x = (long long)(EADV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EADV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_87(void) {
#ifdef WSAEFAULT
	dump("defined", 1);
	if ((WSAEFAULT) <= 0) {
	    long long x = (long long)(WSAEFAULT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEFAULT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_88(void) {
#ifdef ETIMEDOUT
	dump("defined", 1);
	if ((ETIMEDOUT) <= 0) {
	    long long x = (long long)(ETIMEDOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ETIMEDOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_89(void) {
#ifdef ENOSYS
	dump("defined", 1);
	if ((ENOSYS) <= 0) {
	    long long x = (long long)(ENOSYS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOSYS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_90(void) {
#ifdef WSAESTALE
	dump("defined", 1);
	if ((WSAESTALE) <= 0) {
	    long long x = (long long)(WSAESTALE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAESTALE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_91(void) {
#ifdef WSAEHOSTUNREACH
	dump("defined", 1);
	if ((WSAEHOSTUNREACH) <= 0) {
	    long long x = (long long)(WSAEHOSTUNREACH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEHOSTUNREACH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_92(void) {
#ifdef WSAENETDOWN
	dump("defined", 1);
	if ((WSAENETDOWN) <= 0) {
	    long long x = (long long)(WSAENETDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENETDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_93(void) {
#ifdef EPROCUNAVAIL
	dump("defined", 1);
	if ((EPROCUNAVAIL) <= 0) {
	    long long x = (long long)(EPROCUNAVAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROCUNAVAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_94(void) {
#ifdef EUSERS
	dump("defined", 1);
	if ((EUSERS) <= 0) {
	    long long x = (long long)(EUSERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EUSERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_95(void) {
#ifdef EALREADY
	dump("defined", 1);
	if ((EALREADY) <= 0) {
	    long long x = (long long)(EALREADY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EALREADY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_96(void) {
#ifdef ENODEV
	dump("defined", 1);
	if ((ENODEV) <= 0) {
	    long long x = (long long)(ENODEV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENODEV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_97(void) {
#ifdef E2BIG
	dump("defined", 1);
	if ((E2BIG) <= 0) {
	    long long x = (long long)(E2BIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(E2BIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_98(void) {
#ifdef ENXIO
	dump("defined", 1);
	if ((ENXIO) <= 0) {
	    long long x = (long long)(ENXIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENXIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_99(void) {
#ifdef WSAN
	dump("defined", 1);
	if ((WSAN) <= 0) {
	    long long x = (long long)(WSAN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_100(void) {
#ifdef EMULTIHOP
	dump("defined", 1);
	if ((EMULTIHOP) <= 0) {
	    long long x = (long long)(EMULTIHOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EMULTIHOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_101(void) {
#ifdef EMFILE
	dump("defined", 1);
	if ((EMFILE) <= 0) {
	    long long x = (long long)(EMFILE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EMFILE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_102(void) {
#ifdef EMLINK
	dump("defined", 1);
	if ((EMLINK) <= 0) {
	    long long x = (long long)(EMLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EMLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_103(void) {
#ifdef EHOSTDOWN
	dump("defined", 1);
	if ((EHOSTDOWN) <= 0) {
	    long long x = (long long)(EHOSTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EHOSTDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_104(void) {
#ifdef EBFONT
	dump("defined", 1);
	if ((EBFONT) <= 0) {
	    long long x = (long long)(EBFONT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBFONT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_105(void) {
#ifdef EBADEXEC
	dump("defined", 1);
	if ((EBADEXEC) <= 0) {
	    long long x = (long long)(EBADEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_106(void) {
#ifdef WSAGETSELECTEVEN
	dump("defined", 1);
	if ((WSAGETSELECTEVEN) <= 0) {
	    long long x = (long long)(WSAGETSELECTEVEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAGETSELECTEVEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_107(void) {
#ifdef EOPNOTSUPP
	dump("defined", 1);
	if ((EOPNOTSUPP) <= 0) {
	    long long x = (long long)(EOPNOTSUPP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EOPNOTSUPP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_108(void) {
#ifdef EBUSY
	dump("defined", 1);
	if ((EBUSY) <= 0) {
	    long long x = (long long)(EBUSY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBUSY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_109(void) {
#ifdef WSAGETASYNCERRO
	dump("defined", 1);
	if ((WSAGETASYNCERRO) <= 0) {
	    long long x = (long long)(WSAGETASYNCERRO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAGETASYNCERRO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_110(void) {
#ifdef ESTRPIPE
	dump("defined", 1);
	if ((ESTRPIPE) <= 0) {
	    long long x = (long long)(ESTRPIPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESTRPIPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_111(void) {
#ifdef EBADARCH
	dump("defined", 1);
	if ((EBADARCH) <= 0) {
	    long long x = (long long)(EBADARCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADARCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_112(void) {
#ifdef ENFILE
	dump("defined", 1);
	if ((ENFILE) <= 0) {
	    long long x = (long long)(ENFILE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENFILE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_113(void) {
#ifdef EBADMSG
	dump("defined", 1);
	if ((EBADMSG) <= 0) {
	    long long x = (long long)(EBADMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_114(void) {
#ifdef EADDRINUSE
	dump("defined", 1);
	if ((EADDRINUSE) <= 0) {
	    long long x = (long long)(EADDRINUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EADDRINUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_115(void) {
#ifdef EXDEV
	dump("defined", 1);
	if ((EXDEV) <= 0) {
	    long long x = (long long)(EXDEV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXDEV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_116(void) {
#ifdef EPROCLIM
	dump("defined", 1);
	if ((EPROCLIM) <= 0) {
	    long long x = (long long)(EPROCLIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROCLIM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_117(void) {
#ifdef WSAESOCKTNOSUPPORT
	dump("defined", 1);
	if ((WSAESOCKTNOSUPPORT) <= 0) {
	    long long x = (long long)(WSAESOCKTNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAESOCKTNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_118(void) {
#ifdef WSAEINPROGRESS
	dump("defined", 1);
	if ((WSAEINPROGRESS) <= 0) {
	    long long x = (long long)(WSAEINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_119(void) {
#ifdef WSAEMFILE
	dump("defined", 1);
	if ((WSAEMFILE) <= 0) {
	    long long x = (long long)(WSAEMFILE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEMFILE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_120(void) {
#ifdef ENOMEM
	dump("defined", 1);
	if ((ENOMEM) <= 0) {
	    long long x = (long long)(ENOMEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOMEM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_121(void) {
#ifdef ENOSR
	dump("defined", 1);
	if ((ENOSR) <= 0) {
	    long long x = (long long)(ENOSR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOSR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_122(void) {
#ifdef ECONNABORTED
	dump("defined", 1);
	if ((ECONNABORTED) <= 0) {
	    long long x = (long long)(ECONNABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECONNABORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_123(void) {
#ifdef EISNAM
	dump("defined", 1);
	if ((EISNAM) <= 0) {
	    long long x = (long long)(EISNAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EISNAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_124(void) {
#ifdef EOWNERDEAD
	dump("defined", 1);
	if ((EOWNERDEAD) <= 0) {
	    long long x = (long long)(EOWNERDEAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EOWNERDEAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_125(void) {
#ifdef WSAVERNOTSUPPORTED
	dump("defined", 1);
	if ((WSAVERNOTSUPPORTED) <= 0) {
	    long long x = (long long)(WSAVERNOTSUPPORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAVERNOTSUPPORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_126(void) {
#ifdef ELIBSCN
	dump("defined", 1);
	if ((ELIBSCN) <= 0) {
	    long long x = (long long)(ELIBSCN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELIBSCN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_127(void) {
#ifdef WSAENOTCONN
	dump("defined", 1);
	if ((WSAENOTCONN) <= 0) {
	    long long x = (long long)(WSAENOTCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENOTCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_128(void) {
#ifdef ENOTCONN
	dump("defined", 1);
	if ((ENOTCONN) <= 0) {
	    long long x = (long long)(ENOTCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_129(void) {
#ifdef EFAULT
	dump("defined", 1);
	if ((EFAULT) <= 0) {
	    long long x = (long long)(EFAULT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EFAULT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_130(void) {
#ifdef ELIBACC
	dump("defined", 1);
	if ((ELIBACC) <= 0) {
	    long long x = (long long)(ELIBACC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELIBACC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_131(void) {
#ifdef ENETUNREACH
	dump("defined", 1);
	if ((ENETUNREACH) <= 0) {
	    long long x = (long long)(ENETUNREACH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENETUNREACH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_132(void) {
#ifdef WSAEISCONN
	dump("defined", 1);
	if ((WSAEISCONN) <= 0) {
	    long long x = (long long)(WSAEISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_133(void) {
#ifdef WSAEOPNOTSUPP
	dump("defined", 1);
	if ((WSAEOPNOTSUPP) <= 0) {
	    long long x = (long long)(WSAEOPNOTSUPP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEOPNOTSUPP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_134(void) {
#ifdef EBADSLT
	dump("defined", 1);
	if ((EBADSLT) <= 0) {
	    long long x = (long long)(EBADSLT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADSLT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_135(void) {
#ifdef EKEYREJECTED
	dump("defined", 1);
	if ((EKEYREJECTED) <= 0) {
	    long long x = (long long)(EKEYREJECTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EKEYREJECTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_136(void) {
#ifdef EDQUOT
	dump("defined", 1);
	if ((EDQUOT) <= 0) {
	    long long x = (long long)(EDQUOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDQUOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_137(void) {
#ifdef EMEDIUMTYPE
	dump("defined", 1);
	if ((EMEDIUMTYPE) <= 0) {
	    long long x = (long long)(EMEDIUMTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EMEDIUMTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_138(void) {
#ifdef ENOENT
	dump("defined", 1);
	if ((ENOENT) <= 0) {
	    long long x = (long long)(ENOENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_139(void) {
#ifdef ESHUTDOWN
	dump("defined", 1);
	if ((ESHUTDOWN) <= 0) {
	    long long x = (long long)(ESHUTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESHUTDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_140(void) {
#ifdef WSAEWOULDBLOCK
	dump("defined", 1);
	if ((WSAEWOULDBLOCK) <= 0) {
	    long long x = (long long)(WSAEWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_141(void) {
#ifdef WSASYSNOTREADY
	dump("defined", 1);
	if ((WSASYSNOTREADY) <= 0) {
	    long long x = (long long)(WSASYSNOTREADY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSASYSNOTREADY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_142(void) {
#ifdef ERPCMISMATCH
	dump("defined", 1);
	if ((ERPCMISMATCH) <= 0) {
	    long long x = (long long)(ERPCMISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERPCMISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_143(void) {
#ifdef EFTYPE
	dump("defined", 1);
	if ((EFTYPE) <= 0) {
	    long long x = (long long)(EFTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EFTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_144(void) {
#ifdef WSAEALREADY
	dump("defined", 1);
	if ((WSAEALREADY) <= 0) {
	    long long x = (long long)(WSAEALREADY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEALREADY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_145(void) {
#ifdef ECOMM
	dump("defined", 1);
	if ((ECOMM) <= 0) {
	    long long x = (long long)(ECOMM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECOMM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_146(void) {
#ifdef WSASY
	dump("defined", 1);
	if ((WSASY) <= 0) {
	    long long x = (long long)(WSASY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSASY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_147(void) {
#ifdef EPROGMISMATCH
	dump("defined", 1);
	if ((EPROGMISMATCH) <= 0) {
	    long long x = (long long)(EPROGMISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROGMISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_148(void) {
#ifdef WSAEPROTOTYPE
	dump("defined", 1);
	if ((WSAEPROTOTYPE) <= 0) {
	    long long x = (long long)(WSAEPROTOTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEPROTOTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_149(void) {
#ifdef WSAESHUTDOWN
	dump("defined", 1);
	if ((WSAESHUTDOWN) <= 0) {
	    long long x = (long long)(WSAESHUTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAESHUTDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_150(void) {
#ifdef WSAEINVAL
	dump("defined", 1);
	if ((WSAEINVAL) <= 0) {
	    long long x = (long long)(WSAEINVAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINVAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_151(void) {
#ifdef WSABASEERR
	dump("defined", 1);
	if ((WSABASEERR) <= 0) {
	    long long x = (long long)(WSABASEERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSABASEERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_152(void) {
#ifdef EROFS
	dump("defined", 1);
	if ((EROFS) <= 0) {
	    long long x = (long long)(EROFS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EROFS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_153(void) {
#ifdef WSAEDISCON
	dump("defined", 1);
	if ((WSAEDISCON) <= 0) {
	    long long x = (long long)(WSAEDISCON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEDISCON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_154(void) {
#ifdef ECONNREFUSED
	dump("defined", 1);
	if ((ECONNREFUSED) <= 0) {
	    long long x = (long long)(ECONNREFUSED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECONNREFUSED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_155(void) {
#ifdef ENOTEMPTY
	dump("defined", 1);
	if ((ENOTEMPTY) <= 0) {
	    long long x = (long long)(ENOTEMPTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTEMPTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_156(void) {
#ifdef EDOM
	dump("defined", 1);
	if ((EDOM) <= 0) {
	    long long x = (long long)(EDOM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDOM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_157(void) {
#ifdef EBADRPC
	dump("defined", 1);
	if ((EBADRPC) <= 0) {
	    long long x = (long long)(EBADRPC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADRPC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_158(void) {
#ifdef EPROGUNAVAIL
	dump("defined", 1);
	if ((EPROGUNAVAIL) <= 0) {
	    long long x = (long long)(EPROGUNAVAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROGUNAVAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_159(void) {
#ifdef ENEEDAUTH
	dump("defined", 1);
	if ((ENEEDAUTH) <= 0) {
	    long long x = (long long)(ENEEDAUTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENEEDAUTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_160(void) {
#ifdef ENOSTR
	dump("defined", 1);
	if ((ENOSTR) <= 0) {
	    long long x = (long long)(ENOSTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOSTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_161(void) {
#ifdef ENOTDIR
	dump("defined", 1);
	if ((ENOTDIR) <= 0) {
	    long long x = (long long)(ENOTDIR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTDIR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_162(void) {
#ifdef EILSEQ
	dump("defined", 1);
	if ((EILSEQ) <= 0) {
	    long long x = (long long)(EILSEQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EILSEQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_163(void) {
#ifdef EACCES
	dump("defined", 1);
	if ((EACCES) <= 0) {
	    long long x = (long long)(EACCES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EACCES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_164(void) {
#ifdef ENOTSUP
	dump("defined", 1);
	if ((ENOTSUP) <= 0) {
	    long long x = (long long)(ENOTSUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTSUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_165(void) {
#ifdef EPWROFF
	dump("defined", 1);
	if ((EPWROFF) <= 0) {
	    long long x = (long long)(EPWROFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPWROFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_166(void) {
#ifdef EOVERFLOW
	dump("defined", 1);
	if ((EOVERFLOW) <= 0) {
	    long long x = (long long)(EOVERFLOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EOVERFLOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_167(void) {
#ifdef ENETDOWN
	dump("defined", 1);
	if ((ENETDOWN) <= 0) {
	    long long x = (long long)(ENETDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENETDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_168(void) {
#ifdef ENOEXEC
	dump("defined", 1);
	if ((ENOEXEC) <= 0) {
	    long long x = (long long)(ENOEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_169(void) {
#ifdef EPFNOSUPPORT
	dump("defined", 1);
	if ((EPFNOSUPPORT) <= 0) {
	    long long x = (long long)(EPFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_170(void) {
#ifdef ERESTART
	dump("defined", 1);
	if ((ERESTART) <= 0) {
	    long long x = (long long)(ERESTART);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERESTART);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_171(void) {
#ifdef EIO
	dump("defined", 1);
	if ((EIO) <= 0) {
	    long long x = (long long)(EIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_172(void) {
#ifdef EBADF
	dump("defined", 1);
	if ((EBADF) <= 0) {
	    long long x = (long long)(EBADF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_173(void) {
#ifdef EBADE
	dump("defined", 1);
	if ((EBADE) <= 0) {
	    long long x = (long long)(EBADE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_174(void) {
#ifdef ENONET
	dump("defined", 1);
	if ((ENONET) <= 0) {
	    long long x = (long long)(ENONET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENONET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_175(void) {
#ifdef ECHRNG
	dump("defined", 1);
	if ((ECHRNG) <= 0) {
	    long long x = (long long)(ECHRNG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHRNG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_176(void) {
#ifdef WSADESCRIPTIO
	dump("defined", 1);
	if ((WSADESCRIPTIO) <= 0) {
	    long long x = (long long)(WSADESCRIPTIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSADESCRIPTIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_177(void) {
#ifdef WSAEACCES
	dump("defined", 1);
	if ((WSAEACCES) <= 0) {
	    long long x = (long long)(WSAEACCES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEACCES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_178(void) {
#ifdef ENOKEY
	dump("defined", 1);
	if ((ENOKEY) <= 0) {
	    long long x = (long long)(ENOKEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOKEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_179(void) {
#ifdef EDOTDOT
	dump("defined", 1);
	if ((EDOTDOT) <= 0) {
	    long long x = (long long)(EDOTDOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EDOTDOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_180(void) {
#ifdef EBADFD
	dump("defined", 1);
	if ((EBADFD) <= 0) {
	    long long x = (long long)(EBADFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_181(void) {
#ifdef EUNATCH
	dump("defined", 1);
	if ((EUNATCH) <= 0) {
	    long long x = (long long)(EUNATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EUNATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_182(void) {
#ifdef EWOULDBLOCK
	dump("defined", 1);
	if ((EWOULDBLOCK) <= 0) {
	    long long x = (long long)(EWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_183(void) {
#ifdef EBADMACHO
	dump("defined", 1);
	if ((EBADMACHO) <= 0) {
	    long long x = (long long)(EBADMACHO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADMACHO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_184(void) {
#ifdef WSAEAFNOSUPPORT
	dump("defined", 1);
	if ((WSAEAFNOSUPPORT) <= 0) {
	    long long x = (long long)(WSAEAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_185(void) {
#ifdef EBADR
	dump("defined", 1);
	if ((EBADR) <= 0) {
	    long long x = (long long)(EBADR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EBADR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_186(void) {
#ifdef EAFNOSUPPORT
	dump("defined", 1);
	if ((EAFNOSUPPORT) <= 0) {
	    long long x = (long long)(EAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_187(void) {
#ifdef WSAENOTSOCK
	dump("defined", 1);
	if ((WSAENOTSOCK) <= 0) {
	    long long x = (long long)(WSAENOTSOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENOTSOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_188(void) {
#ifdef ESRCH
	dump("defined", 1);
	if ((ESRCH) <= 0) {
	    long long x = (long long)(ESRCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESRCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_189(void) {
#ifdef WSAECONNABORTED
	dump("defined", 1);
	if ((WSAECONNABORTED) <= 0) {
	    long long x = (long long)(WSAECONNABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAECONNABORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_190(void) {
#ifdef ENOMEDIUM
	dump("defined", 1);
	if ((ENOMEDIUM) <= 0) {
	    long long x = (long long)(ENOMEDIUM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOMEDIUM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_191(void) {
#ifdef EPROTOTYPE
	dump("defined", 1);
	if ((EPROTOTYPE) <= 0) {
	    long long x = (long long)(EPROTOTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPROTOTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_192(void) {
#ifdef ENAVAIL
	dump("defined", 1);
	if ((ENAVAIL) <= 0) {
	    long long x = (long long)(ENAVAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENAVAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_193(void) {
#ifdef EKEYREVOKED
	dump("defined", 1);
	if ((EKEYREVOKED) <= 0) {
	    long long x = (long long)(EKEYREVOKED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EKEYREVOKED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_194(void) {
#ifdef WSAMAKEASYNCREPL
	dump("defined", 1);
	if ((WSAMAKEASYNCREPL) <= 0) {
	    long long x = (long long)(WSAMAKEASYNCREPL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAMAKEASYNCREPL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_195(void) {
#ifdef WSAEUSERS
	dump("defined", 1);
	if ((WSAEUSERS) <= 0) {
	    long long x = (long long)(WSAEUSERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEUSERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_196(void) {
#ifdef WSANOTINITIALISED
	dump("defined", 1);
	if ((WSANOTINITIALISED) <= 0) {
	    long long x = (long long)(WSANOTINITIALISED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSANOTINITIALISED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_197(void) {
#ifdef EPIPE
	dump("defined", 1);
	if ((EPIPE) <= 0) {
	    long long x = (long long)(EPIPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPIPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_198(void) {
#ifdef EINVAL
	dump("defined", 1);
	if ((EINVAL) <= 0) {
	    long long x = (long long)(EINVAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINVAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_199(void) {
#ifdef ENOTBLK
	dump("defined", 1);
	if ((ENOTBLK) <= 0) {
	    long long x = (long long)(ENOTBLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOTBLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_200(void) {
#ifdef ENODATA
	dump("defined", 1);
	if ((ENODATA) <= 0) {
	    long long x = (long long)(ENODATA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENODATA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_201(void) {
#ifdef ELOCKUNMAPPED
	dump("defined", 1);
	if ((ELOCKUNMAPPED) <= 0) {
	    long long x = (long long)(ELOCKUNMAPPED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ELOCKUNMAPPED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_202(void) {
#ifdef WSAELOOP
	dump("defined", 1);
	if ((WSAELOOP) <= 0) {
	    long long x = (long long)(WSAELOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAELOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_203(void) {
#ifdef EL2HLT
	dump("defined", 1);
	if ((EL2HLT) <= 0) {
	    long long x = (long long)(EL2HLT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EL2HLT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_204(void) {
#ifdef ESHLIBVERS
	dump("defined", 1);
	if ((ESHLIBVERS) <= 0) {
	    long long x = (long long)(ESHLIBVERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ESHLIBVERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_205(void) {
#ifdef EL2NSYNC
	dump("defined", 1);
	if ((EL2NSYNC) <= 0) {
	    long long x = (long long)(EL2NSYNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EL2NSYNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_206(void) {
#ifdef ERANGE
	dump("defined", 1);
	if ((ERANGE) <= 0) {
	    long long x = (long long)(ERANGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERANGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_207(void) {
#ifdef ENOMSG
	dump("defined", 1);
	if ((ENOMSG) <= 0) {
	    long long x = (long long)(ENOMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_208(void) {
#ifdef WSAENETUNREACH
	dump("defined", 1);
	if ((WSAENETUNREACH) <= 0) {
	    long long x = (long long)(WSAENETUNREACH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAENETUNREACH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_209(void) {
#ifdef EHOSTUNREACH
	dump("defined", 1);
	if ((EHOSTUNREACH) <= 0) {
	    long long x = (long long)(EHOSTUNREACH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EHOSTUNREACH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_210(void) {
#ifdef ENOCSI
	dump("defined", 1);
	if ((ENOCSI) <= 0) {
	    long long x = (long long)(ENOCSI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ENOCSI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	printf("-+- 4\n");
	dump_section_4();
	printf("---\n");
	printf("-+- 5\n");
	dump_section_5();
	printf("---\n");
	printf("-+- 6\n");
	dump_section_6();
	printf("---\n");
	printf("-+- 7\n");
	dump_section_7();
	printf("---\n");
	printf("-+- 8\n");
	dump_section_8();
	printf("---\n");
	printf("-+- 9\n");
	dump_section_9();
	printf("---\n");
	printf("-+- 10\n");
	dump_section_10();
	printf("---\n");
	printf("-+- 11\n");
	dump_section_11();
	printf("---\n");
	printf("-+- 12\n");
	dump_section_12();
	printf("---\n");
	printf("-+- 13\n");
	dump_section_13();
	printf("---\n");
	printf("-+- 14\n");
	dump_section_14();
	printf("---\n");
	printf("-+- 15\n");
	dump_section_15();
	printf("---\n");
	printf("-+- 16\n");
	dump_section_16();
	printf("---\n");
	printf("-+- 17\n");
	dump_section_17();
	printf("---\n");
	printf("-+- 18\n");
	dump_section_18();
	printf("---\n");
	printf("-+- 19\n");
	dump_section_19();
	printf("---\n");
	printf("-+- 20\n");
	dump_section_20();
	printf("---\n");
	printf("-+- 21\n");
	dump_section_21();
	printf("---\n");
	printf("-+- 22\n");
	dump_section_22();
	printf("---\n");
	printf("-+- 23\n");
	dump_section_23();
	printf("---\n");
	printf("-+- 24\n");
	dump_section_24();
	printf("---\n");
	printf("-+- 25\n");
	dump_section_25();
	printf("---\n");
	printf("-+- 26\n");
	dump_section_26();
	printf("---\n");
	printf("-+- 27\n");
	dump_section_27();
	printf("---\n");
	printf("-+- 28\n");
	dump_section_28();
	printf("---\n");
	printf("-+- 29\n");
	dump_section_29();
	printf("---\n");
	printf("-+- 30\n");
	dump_section_30();
	printf("---\n");
	printf("-+- 31\n");
	dump_section_31();
	printf("---\n");
	printf("-+- 32\n");
	dump_section_32();
	printf("---\n");
	printf("-+- 33\n");
	dump_section_33();
	printf("---\n");
	printf("-+- 34\n");
	dump_section_34();
	printf("---\n");
	printf("-+- 35\n");
	dump_section_35();
	printf("---\n");
	printf("-+- 36\n");
	dump_section_36();
	printf("---\n");
	printf("-+- 37\n");
	dump_section_37();
	printf("---\n");
	printf("-+- 38\n");
	dump_section_38();
	printf("---\n");
	printf("-+- 39\n");
	dump_section_39();
	printf("---\n");
	printf("-+- 40\n");
	dump_section_40();
	printf("---\n");
	printf("-+- 41\n");
	dump_section_41();
	printf("---\n");
	printf("-+- 42\n");
	dump_section_42();
	printf("---\n");
	printf("-+- 43\n");
	dump_section_43();
	printf("---\n");
	printf("-+- 44\n");
	dump_section_44();
	printf("---\n");
	printf("-+- 45\n");
	dump_section_45();
	printf("---\n");
	printf("-+- 46\n");
	dump_section_46();
	printf("---\n");
	printf("-+- 47\n");
	dump_section_47();
	printf("---\n");
	printf("-+- 48\n");
	dump_section_48();
	printf("---\n");
	printf("-+- 49\n");
	dump_section_49();
	printf("---\n");
	printf("-+- 50\n");
	dump_section_50();
	printf("---\n");
	printf("-+- 51\n");
	dump_section_51();
	printf("---\n");
	printf("-+- 52\n");
	dump_section_52();
	printf("---\n");
	printf("-+- 53\n");
	dump_section_53();
	printf("---\n");
	printf("-+- 54\n");
	dump_section_54();
	printf("---\n");
	printf("-+- 55\n");
	dump_section_55();
	printf("---\n");
	printf("-+- 56\n");
	dump_section_56();
	printf("---\n");
	printf("-+- 57\n");
	dump_section_57();
	printf("---\n");
	printf("-+- 58\n");
	dump_section_58();
	printf("---\n");
	printf("-+- 59\n");
	dump_section_59();
	printf("---\n");
	printf("-+- 60\n");
	dump_section_60();
	printf("---\n");
	printf("-+- 61\n");
	dump_section_61();
	printf("---\n");
	printf("-+- 62\n");
	dump_section_62();
	printf("---\n");
	printf("-+- 63\n");
	dump_section_63();
	printf("---\n");
	printf("-+- 64\n");
	dump_section_64();
	printf("---\n");
	printf("-+- 65\n");
	dump_section_65();
	printf("---\n");
	printf("-+- 66\n");
	dump_section_66();
	printf("---\n");
	printf("-+- 67\n");
	dump_section_67();
	printf("---\n");
	printf("-+- 68\n");
	dump_section_68();
	printf("---\n");
	printf("-+- 69\n");
	dump_section_69();
	printf("---\n");
	printf("-+- 70\n");
	dump_section_70();
	printf("---\n");
	printf("-+- 71\n");
	dump_section_71();
	printf("---\n");
	printf("-+- 72\n");
	dump_section_72();
	printf("---\n");
	printf("-+- 73\n");
	dump_section_73();
	printf("---\n");
	printf("-+- 74\n");
	dump_section_74();
	printf("---\n");
	printf("-+- 75\n");
	dump_section_75();
	printf("---\n");
	printf("-+- 76\n");
	dump_section_76();
	printf("---\n");
	printf("-+- 77\n");
	dump_section_77();
	printf("---\n");
	printf("-+- 78\n");
	dump_section_78();
	printf("---\n");
	printf("-+- 79\n");
	dump_section_79();
	printf("---\n");
	printf("-+- 80\n");
	dump_section_80();
	printf("---\n");
	printf("-+- 81\n");
	dump_section_81();
	printf("---\n");
	printf("-+- 82\n");
	dump_section_82();
	printf("---\n");
	printf("-+- 83\n");
	dump_section_83();
	printf("---\n");
	printf("-+- 84\n");
	dump_section_84();
	printf("---\n");
	printf("-+- 85\n");
	dump_section_85();
	printf("---\n");
	printf("-+- 86\n");
	dump_section_86();
	printf("---\n");
	printf("-+- 87\n");
	dump_section_87();
	printf("---\n");
	printf("-+- 88\n");
	dump_section_88();
	printf("---\n");
	printf("-+- 89\n");
	dump_section_89();
	printf("---\n");
	printf("-+- 90\n");
	dump_section_90();
	printf("---\n");
	printf("-+- 91\n");
	dump_section_91();
	printf("---\n");
	printf("-+- 92\n");
	dump_section_92();
	printf("---\n");
	printf("-+- 93\n");
	dump_section_93();
	printf("---\n");
	printf("-+- 94\n");
	dump_section_94();
	printf("---\n");
	printf("-+- 95\n");
	dump_section_95();
	printf("---\n");
	printf("-+- 96\n");
	dump_section_96();
	printf("---\n");
	printf("-+- 97\n");
	dump_section_97();
	printf("---\n");
	printf("-+- 98\n");
	dump_section_98();
	printf("---\n");
	printf("-+- 99\n");
	dump_section_99();
	printf("---\n");
	printf("-+- 100\n");
	dump_section_100();
	printf("---\n");
	printf("-+- 101\n");
	dump_section_101();
	printf("---\n");
	printf("-+- 102\n");
	dump_section_102();
	printf("---\n");
	printf("-+- 103\n");
	dump_section_103();
	printf("---\n");
	printf("-+- 104\n");
	dump_section_104();
	printf("---\n");
	printf("-+- 105\n");
	dump_section_105();
	printf("---\n");
	printf("-+- 106\n");
	dump_section_106();
	printf("---\n");
	printf("-+- 107\n");
	dump_section_107();
	printf("---\n");
	printf("-+- 108\n");
	dump_section_108();
	printf("---\n");
	printf("-+- 109\n");
	dump_section_109();
	printf("---\n");
	printf("-+- 110\n");
	dump_section_110();
	printf("---\n");
	printf("-+- 111\n");
	dump_section_111();
	printf("---\n");
	printf("-+- 112\n");
	dump_section_112();
	printf("---\n");
	printf("-+- 113\n");
	dump_section_113();
	printf("---\n");
	printf("-+- 114\n");
	dump_section_114();
	printf("---\n");
	printf("-+- 115\n");
	dump_section_115();
	printf("---\n");
	printf("-+- 116\n");
	dump_section_116();
	printf("---\n");
	printf("-+- 117\n");
	dump_section_117();
	printf("---\n");
	printf("-+- 118\n");
	dump_section_118();
	printf("---\n");
	printf("-+- 119\n");
	dump_section_119();
	printf("---\n");
	printf("-+- 120\n");
	dump_section_120();
	printf("---\n");
	printf("-+- 121\n");
	dump_section_121();
	printf("---\n");
	printf("-+- 122\n");
	dump_section_122();
	printf("---\n");
	printf("-+- 123\n");
	dump_section_123();
	printf("---\n");
	printf("-+- 124\n");
	dump_section_124();
	printf("---\n");
	printf("-+- 125\n");
	dump_section_125();
	printf("---\n");
	printf("-+- 126\n");
	dump_section_126();
	printf("---\n");
	printf("-+- 127\n");
	dump_section_127();
	printf("---\n");
	printf("-+- 128\n");
	dump_section_128();
	printf("---\n");
	printf("-+- 129\n");
	dump_section_129();
	printf("---\n");
	printf("-+- 130\n");
	dump_section_130();
	printf("---\n");
	printf("-+- 131\n");
	dump_section_131();
	printf("---\n");
	printf("-+- 132\n");
	dump_section_132();
	printf("---\n");
	printf("-+- 133\n");
	dump_section_133();
	printf("---\n");
	printf("-+- 134\n");
	dump_section_134();
	printf("---\n");
	printf("-+- 135\n");
	dump_section_135();
	printf("---\n");
	printf("-+- 136\n");
	dump_section_136();
	printf("---\n");
	printf("-+- 137\n");
	dump_section_137();
	printf("---\n");
	printf("-+- 138\n");
	dump_section_138();
	printf("---\n");
	printf("-+- 139\n");
	dump_section_139();
	printf("---\n");
	printf("-+- 140\n");
	dump_section_140();
	printf("---\n");
	printf("-+- 141\n");
	dump_section_141();
	printf("---\n");
	printf("-+- 142\n");
	dump_section_142();
	printf("---\n");
	printf("-+- 143\n");
	dump_section_143();
	printf("---\n");
	printf("-+- 144\n");
	dump_section_144();
	printf("---\n");
	printf("-+- 145\n");
	dump_section_145();
	printf("---\n");
	printf("-+- 146\n");
	dump_section_146();
	printf("---\n");
	printf("-+- 147\n");
	dump_section_147();
	printf("---\n");
	printf("-+- 148\n");
	dump_section_148();
	printf("---\n");
	printf("-+- 149\n");
	dump_section_149();
	printf("---\n");
	printf("-+- 150\n");
	dump_section_150();
	printf("---\n");
	printf("-+- 151\n");
	dump_section_151();
	printf("---\n");
	printf("-+- 152\n");
	dump_section_152();
	printf("---\n");
	printf("-+- 153\n");
	dump_section_153();
	printf("---\n");
	printf("-+- 154\n");
	dump_section_154();
	printf("---\n");
	printf("-+- 155\n");
	dump_section_155();
	printf("---\n");
	printf("-+- 156\n");
	dump_section_156();
	printf("---\n");
	printf("-+- 157\n");
	dump_section_157();
	printf("---\n");
	printf("-+- 158\n");
	dump_section_158();
	printf("---\n");
	printf("-+- 159\n");
	dump_section_159();
	printf("---\n");
	printf("-+- 160\n");
	dump_section_160();
	printf("---\n");
	printf("-+- 161\n");
	dump_section_161();
	printf("---\n");
	printf("-+- 162\n");
	dump_section_162();
	printf("---\n");
	printf("-+- 163\n");
	dump_section_163();
	printf("---\n");
	printf("-+- 164\n");
	dump_section_164();
	printf("---\n");
	printf("-+- 165\n");
	dump_section_165();
	printf("---\n");
	printf("-+- 166\n");
	dump_section_166();
	printf("---\n");
	printf("-+- 167\n");
	dump_section_167();
	printf("---\n");
	printf("-+- 168\n");
	dump_section_168();
	printf("---\n");
	printf("-+- 169\n");
	dump_section_169();
	printf("---\n");
	printf("-+- 170\n");
	dump_section_170();
	printf("---\n");
	printf("-+- 171\n");
	dump_section_171();
	printf("---\n");
	printf("-+- 172\n");
	dump_section_172();
	printf("---\n");
	printf("-+- 173\n");
	dump_section_173();
	printf("---\n");
	printf("-+- 174\n");
	dump_section_174();
	printf("---\n");
	printf("-+- 175\n");
	dump_section_175();
	printf("---\n");
	printf("-+- 176\n");
	dump_section_176();
	printf("---\n");
	printf("-+- 177\n");
	dump_section_177();
	printf("---\n");
	printf("-+- 178\n");
	dump_section_178();
	printf("---\n");
	printf("-+- 179\n");
	dump_section_179();
	printf("---\n");
	printf("-+- 180\n");
	dump_section_180();
	printf("---\n");
	printf("-+- 181\n");
	dump_section_181();
	printf("---\n");
	printf("-+- 182\n");
	dump_section_182();
	printf("---\n");
	printf("-+- 183\n");
	dump_section_183();
	printf("---\n");
	printf("-+- 184\n");
	dump_section_184();
	printf("---\n");
	printf("-+- 185\n");
	dump_section_185();
	printf("---\n");
	printf("-+- 186\n");
	dump_section_186();
	printf("---\n");
	printf("-+- 187\n");
	dump_section_187();
	printf("---\n");
	printf("-+- 188\n");
	dump_section_188();
	printf("---\n");
	printf("-+- 189\n");
	dump_section_189();
	printf("---\n");
	printf("-+- 190\n");
	dump_section_190();
	printf("---\n");
	printf("-+- 191\n");
	dump_section_191();
	printf("---\n");
	printf("-+- 192\n");
	dump_section_192();
	printf("---\n");
	printf("-+- 193\n");
	dump_section_193();
	printf("---\n");
	printf("-+- 194\n");
	dump_section_194();
	printf("---\n");
	printf("-+- 195\n");
	dump_section_195();
	printf("---\n");
	printf("-+- 196\n");
	dump_section_196();
	printf("---\n");
	printf("-+- 197\n");
	dump_section_197();
	printf("---\n");
	printf("-+- 198\n");
	dump_section_198();
	printf("---\n");
	printf("-+- 199\n");
	dump_section_199();
	printf("---\n");
	printf("-+- 200\n");
	dump_section_200();
	printf("---\n");
	printf("-+- 201\n");
	dump_section_201();
	printf("---\n");
	printf("-+- 202\n");
	dump_section_202();
	printf("---\n");
	printf("-+- 203\n");
	dump_section_203();
	printf("---\n");
	printf("-+- 204\n");
	dump_section_204();
	printf("---\n");
	printf("-+- 205\n");
	dump_section_205();
	printf("---\n");
	printf("-+- 206\n");
	dump_section_206();
	printf("---\n");
	printf("-+- 207\n");
	dump_section_207();
	printf("---\n");
	printf("-+- 208\n");
	dump_section_208();
	printf("---\n");
	printf("-+- 209\n");
	dump_section_209();
	printf("---\n");
	printf("-+- 210\n");
	dump_section_210();
	printf("---\n");
	return 0;
}
