/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200809L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#ifdef _WIN32
#  define inline _inline
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <stdarg.h>
#include <stdio.h>
#include <stddef.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_object.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_moduleobject.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_memoryobject.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_unicodeobject.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef _PyASCIIObject_state_t platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs interned", offsetof(platcheck_t, interned));
	dump("fldsize interned",   sizeof(s.interned));
	s.interned = 0; s.interned = ~s.interned;
	dump("fldunsigned interned", s.interned > 0);
	dump("fldofs kind", offsetof(platcheck_t, kind));
	dump("fldsize kind",   sizeof(s.kind));
	s.kind = 0; s.kind = ~s.kind;
	dump("fldunsigned kind", s.kind > 0);
	dump("fldofs compact", offsetof(platcheck_t, compact));
	dump("fldsize compact",   sizeof(s.compact));
	s.compact = 0; s.compact = ~s.compact;
	dump("fldunsigned compact", s.compact > 0);
	dump("fldofs ascii", offsetof(platcheck_t, ascii));
	dump("fldsize ascii",   sizeof(s.ascii));
	s.ascii = 0; s.ascii = ~s.ascii;
	dump("fldunsigned ascii", s.ascii > 0);
	dump("fldofs ready", offsetof(platcheck_t, ready));
	dump("fldsize ready",   sizeof(s.ready));
	s.ready = 0; s.ready = ~s.ready;
	dump("fldunsigned ready", s.ready > 0);
}

void dump_section_1(void) {
	typedef PyASCIIObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs length", offsetof(platcheck_t, length));
	dump("fldsize length",   sizeof(s.length));
	s.length = 0; s.length = ~s.length;
	dump("fldunsigned length", s.length > 0);
	dump("fldofs state", offsetof(platcheck_t, state));
	dump("fldsize state",   sizeof(s.state));
	dump("fldofs wstr", offsetof(platcheck_t, wstr));
	dump("fldsize wstr",   sizeof(s.wstr));
}

void dump_section_2(void) {
	typedef PyCompactUnicodeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs _base", offsetof(platcheck_t, _base));
	dump("fldsize _base",   sizeof(s._base));
	dump("fldofs utf8_length", offsetof(platcheck_t, utf8_length));
	dump("fldsize utf8_length",   sizeof(s.utf8_length));
	s.utf8_length = 0; s.utf8_length = ~s.utf8_length;
	dump("fldunsigned utf8_length", s.utf8_length > 0);
	dump("fldofs utf8", offsetof(platcheck_t, utf8));
	dump("fldsize utf8",   sizeof(s.utf8));
	dump("fldofs wstr_length", offsetof(platcheck_t, wstr_length));
	dump("fldsize wstr_length",   sizeof(s.wstr_length));
	s.wstr_length = 0; s.wstr_length = ~s.wstr_length;
	dump("fldunsigned wstr_length", s.wstr_length > 0);
}

void dump_section_3(void) {
	typedef PyUnicodeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs _base", offsetof(platcheck_t, _base));
	dump("fldsize _base",   sizeof(s._base));
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	return 0;
}
