/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2008 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200809L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#  define RPY_UNUSED __attribute__ ((__unused__))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#  define RPY_UNUSED   /*nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif

#ifdef _WIN32
#  define inline _inline
#endif

#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <stdarg.h>
#include <stdio.h>
#include <stddef.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_object.h>
#include </var/tmp/portage/dev-python/pypy3-7.1.0/work/pypy3.6-v7.1.0-src/pypy/module/cpyext/parse/cpyext_moduleobject.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_0(void) {
	typedef PyModuleDef_Base platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs m_init", offsetof(platcheck_t, m_init));
	dump("fldsize m_init",   sizeof(s.m_init));
	dump("fldofs m_index", offsetof(platcheck_t, m_index));
	dump("fldsize m_index",   sizeof(s.m_index));
	s.m_index = 0; s.m_index = ~s.m_index;
	dump("fldunsigned m_index", s.m_index > 0);
	dump("fldofs m_copy", offsetof(platcheck_t, m_copy));
	dump("fldsize m_copy",   sizeof(s.m_copy));
}

void dump_section_1(void) {
	typedef PyModuleDef_Slot platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs slot", offsetof(platcheck_t, slot));
	dump("fldsize slot",   sizeof(s.slot));
	dump("fldofs value", offsetof(platcheck_t, value));
	dump("fldsize value",   sizeof(s.value));
}

void dump_section_2(void) {
	typedef PyModuleDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs m_base", offsetof(platcheck_t, m_base));
	dump("fldsize m_base",   sizeof(s.m_base));
	dump("fldofs m_name", offsetof(platcheck_t, m_name));
	dump("fldsize m_name",   sizeof(s.m_name));
	dump("fldofs m_doc", offsetof(platcheck_t, m_doc));
	dump("fldsize m_doc",   sizeof(s.m_doc));
	dump("fldofs m_size", offsetof(platcheck_t, m_size));
	dump("fldsize m_size",   sizeof(s.m_size));
	s.m_size = 0; s.m_size = ~s.m_size;
	dump("fldunsigned m_size", s.m_size > 0);
	dump("fldofs m_methods", offsetof(platcheck_t, m_methods));
	dump("fldsize m_methods",   sizeof(s.m_methods));
	dump("fldofs m_slots", offsetof(platcheck_t, m_slots));
	dump("fldsize m_slots",   sizeof(s.m_slots));
	dump("fldofs m_traverse", offsetof(platcheck_t, m_traverse));
	dump("fldsize m_traverse",   sizeof(s.m_traverse));
	dump("fldofs m_clear", offsetof(platcheck_t, m_clear));
	dump("fldsize m_clear",   sizeof(s.m_clear));
	dump("fldofs m_free", offsetof(platcheck_t, m_free));
	dump("fldsize m_free",   sizeof(s.m_free));
}

void dump_section_3(void) {
	typedef PyModuleObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs md_def", offsetof(platcheck_t, md_def));
	dump("fldsize md_def",   sizeof(s.md_def));
	dump("fldofs md_state", offsetof(platcheck_t, md_state));
	dump("fldsize md_state",   sizeof(s.md_state));
}

int main(int argc, char *argv[]) {
	printf("-+- 0\n");
	dump_section_0();
	printf("---\n");
	printf("-+- 1\n");
	dump_section_1();
	printf("---\n");
	printf("-+- 2\n");
	dump_section_2();
	printf("---\n");
	printf("-+- 3\n");
	dump_section_3();
	printf("---\n");
	return 0;
}
